[![Build and Release Python Package](https://github.com/softwrdai/ML-FUZZY-C-MEANS/actions/workflows/release_package.yaml/badge.svg)](https://github.com/softwrdai/ML-FUZZY-C-MEANS/actions/workflows/release_package.yaml)


# ml-fuzzy-c-means
This package will be a unified implementation of the fuzzy c-means clustering algorithm, a popular method for clustering data points into distinct groups.

## Download the package
* Please go to the release page to download the package ``*.whl`` file
* After downloading the package, please run the following command to install the package
```bash
pip install fcmeans_softwrd
```

## How to use the package

* Once done the installation mentioned in the above section [Download the package](#download-the-package), please import the package in your python code as follows
```python
import fcm

fcm.__version__

```
